Index: uspace/lib/c/arch/ia64/src/entry.S
===================================================================
--- uspace/lib/c/arch/ia64/src/entry.S	(revision 4f205248dfb2dd7692ef1b857648ba9d96fe496c)
+++ uspace/lib/c/arch/ia64/src/entry.S	(revision e63468473345cf0a982276dc4d69b496d2a0f7ec)
@@ -41,6 +41,6 @@
 	movl gp = __gp
 
 	# Pass PCB pointer as the first argument to __main
 	mov out0 = r2 ;;
-	br.call.sptk.many b0 = __main
+	br.call.sptk.many b0 = __libc_main
 
@@ -41,6 +41,6 @@
 	movl gp = __gp
 
-	# Pass PCB pointer as the first argument to __main
+	# Pass PCB pointer as the first argument to __libc_main
 	mov out0 = r2 ;;
